/**
 * Types are text,password,radio,chckbox,select
 *
 * Field Values
 * - displayName" required="true" type="string"
 * - name" required="true" type="string"
 * - defaultValue" required="false" type="string" default=""
 * - required" required="false" type="boolean" default="no"
 * - description" required="false" type="any" default=""
 * - type" required="false" type="string" default="text"
 * - values" required="false" type="string" default=""
 */
component extends="Cache"{

	fields = [
		field(
			displayName  = "Host",
			name         = "host",
			defaultValue = "127.0.0.1",
			required     = true,
			description  = "The ip or hostname of the Redis server",
			type         = "text"
		),
		field(
			displayName = "Port",
			name          = "port",
			defaultValue  = "6379",
			required      = true,
			description   = "The port Redis is listening on",
			type          = "text"
		),
		field(
			displayName = "Password",
			name          = "password",
			defaultValue  = "",
			required      = false,
			description   = "The Redis password",
			type          = "password"
		),
		field(
			displayName 	= "Use SSL",
			name          	= "useSSL",
			defaultValue  	= false,
			required      	= false,
			description   	= "Use SSL on the connection",
			type          	= "select",
			values 			= "true,false"
		),
		field(
			displayName = "Connection Timeout",
			name          = "timeout",
			defaultValue  = "2000",
			required      = false,
			description   = "The connection timeout in milliseconds",
			type          = "text"
		),
		field(
			displayName = "Max Connections",
			name          = "maxConnections",
			defaultValue  = "50",
			required      = false,
			description   = "Max connections to Redis",
			type          = "text"
		),
		field(
			displayName = "Idle Connections",
			name          = "idleConnections",
			defaultValue  = "5",
			required      = false,
			description   = "Max idle connections to Redis",
			type          = "text"
		),
		field(
			displayName   = "Cache Key Prefix",
			name          = "keyprefix",
			defaultValue  = "lucee-cache",
			required      = true,
			description   = "The unique cache key prefix to be used when storing keys from this cache. Remember that multiple caches can be registered against the same Redis instance. This will avoid collisions betwee Lucee caches."
		)
	];

	function getClass(){
		return "ortus.extension.cache.redis.RedisCache";
	}

	function getLabel(){
		return "Ortus Redis Cache";
	}

	function getDescription(){
		return "Ortus Redis Cache Extension will allow you to register caches so they can store their content on a distributed and highly scalable Redis cluster.  You can also use the extension for distributed session/client management, object functions and much more.{trial-description}";
	}

}